@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/builtin-toplevel.c,v 1.29 2005/01/14 05:44:00 keithp Exp $ */
+/* $Header$ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -256,7 +256,8 @@ Value
 do_time (void)
 {
     ENTER ();
-    RETURN (NewInt (time (0)));
+    RETURN (Reduce (NewInteger (Positive, 
+				NewDoubleDigitNatural ((double_digit) time(0)))));
 }
 
 Value
